diff --git a/samples/DOMCount/DOMCount.cpp b/samples/DOMCount/DOMCount.cpp
index 80834df3042c35fb04c38f7a79530f3d942f21ba..b7b69a03aebcbb1ab6130f2993f8dc4f87ee417b 100644
--- a/samples/DOMCount/DOMCount.cpp
+++ b/samples/DOMCount/DOMCount.cpp
@@ -284,7 +284,7 @@ int main(int argC, char* argV[])
         //
         if (errorHandler.getSawErrors())
         {
-            cout << "\nErrors occured, no output available\n" << endl;
+            cout << "\nErrors occurred, no output available\n" << endl;
             errorOccurred = true;
         }
          else
diff --git a/samples/DOMPrint/DOMPrint.cpp b/samples/DOMPrint/DOMPrint.cpp
index e7102c3808b70952364a1256b99c6d8aa0b23f96..23feb2729e4a72c11333e8ca235464ba7bf6b8db 100644
--- a/samples/DOMPrint/DOMPrint.cpp
+++ b/samples/DOMPrint/DOMPrint.cpp
@@ -457,7 +457,7 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& e)
     {
-        cerr << "An error occured during parsing\n   Message: "
+        cerr << "An error occurred during parsing\n   Message: "
              << DOMString(e.getMessage()) << endl;
         errorsOccured = true;
     }
@@ -465,14 +465,14 @@ int main(int argC, char* argV[])
 
     catch (const DOM_DOMException& e)
     {
-       cerr << "A DOM error occured during parsing\n   DOMException code: "
+       cerr << "A DOM error occurred during parsing\n   DOMException code: "
              << e.code << endl;
         errorsOccured = true;
     }
 
     catch (...)
     {
-        cerr << "An error occured during parsing\n " << endl;
+        cerr << "An error occurred during parsing\n " << endl;
         errorsOccured = true;
     }
 
diff --git a/samples/EnumVal/EnumVal.cpp b/samples/EnumVal/EnumVal.cpp
index f4524dbc138e478499052d17a0b5b381b04d8869..d0abcc387d19291a166e64ecddd710445b7ef834 100644
--- a/samples/EnumVal/EnumVal.cpp
+++ b/samples/EnumVal/EnumVal.cpp
@@ -56,6 +56,9 @@
 
 /*
  * $Log$
+ * Revision 1.17  2002/04/17 20:18:08  tng
+ * [Bug 7493] The word "occured" is misspelled and it is a global error.
+ *
  * Revision 1.16  2002/02/01 22:35:51  peiyongz
  * sane_include
  *
@@ -339,7 +342,7 @@ int main(int argC, char* argV[])
         }
     }
     else
-        cout << "\nErrors occured, no output available\n" << endl;
+        cout << "\nErrors occurred, no output available\n" << endl;
 
     //
     //  Delete the parser itself.  Must be done prior to calling Terminate, below.
diff --git a/samples/IDOMCount/IDOMCount.cpp b/samples/IDOMCount/IDOMCount.cpp
index 7503135e0ec4b481da9362d28ed05dda679cc57a..c776dc30c0ff284e0c5549186def14fbcf5e027c 100644
--- a/samples/IDOMCount/IDOMCount.cpp
+++ b/samples/IDOMCount/IDOMCount.cpp
@@ -315,7 +315,7 @@ int main(int argC, char* argV[])
         //
         if (errorHandler.getSawErrors())
         {
-            cout << "\nErrors occured, no output available\n" << endl;
+            cout << "\nErrors occurred, no output available\n" << endl;
             errorOccurred = true;
         }
          else
@@ -327,7 +327,7 @@ int main(int argC, char* argV[])
                 // test getElementsByTagName and getLength
                 XMLCh xa[] = {chAsterisk, chNull};
                 if (elementCount != doc->getElementsByTagName(xa)->getLength()) {
-                    cout << "\nErrors occured, element count is wrong\n" << endl;
+                    cout << "\nErrors occurred, element count is wrong\n" << endl;
                     errorOccurred = true;
                 }
             }
diff --git a/samples/IDOMPrint/IDOMPrint.cpp b/samples/IDOMPrint/IDOMPrint.cpp
index 1ac62edbd1594e4d5779a36f86c9f86efccfd2d5..74aa4fda6b606da62c81808d2a6f3e971467334a 100644
--- a/samples/IDOMPrint/IDOMPrint.cpp
+++ b/samples/IDOMPrint/IDOMPrint.cpp
@@ -450,7 +450,7 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& e)
     {
-        cerr << "An error occured during parsing\n   Message: "
+        cerr << "An error occurred during parsing\n   Message: "
              << StrX(e.getMessage()) << endl;
         errorsOccured = true;
     }
@@ -458,14 +458,14 @@ int main(int argC, char* argV[])
 
     catch (const IDOM_DOMException& e)
     {
-       cerr << "A DOM error occured during parsing\n   DOMException code: "
+       cerr << "A DOM error occurred during parsing\n   DOMException code: "
              << e.code << endl;
         errorsOccured = true;
     }
 
     catch (...)
     {
-        cerr << "An error occured during parsing\n " << endl;
+        cerr << "An error occurred during parsing\n " << endl;
         errorsOccured = true;
     }
 
diff --git a/samples/PParse/PParse.cpp b/samples/PParse/PParse.cpp
index 5daa87fc2d02dfc6cab76a677b9f68286e7735bf..e9e6ebdb6059a77522f278653101df74ce299d36 100644
--- a/samples/PParse/PParse.cpp
+++ b/samples/PParse/PParse.cpp
@@ -56,6 +56,9 @@
 
 /*
  * $Log$
+ * Revision 1.14  2002/04/17 20:18:08  tng
+ * [Bug 7493] The word "occured" is misspelled and it is a global error.
+ *
  * Revision 1.13  2002/02/01 22:37:38  peiyongz
  * sane_include
  *
@@ -341,7 +344,7 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& toCatch)
     {
-        cerr << "\nAn error occured: '" << xmlFile << "'\n"
+        cerr << "\nAn error occurred: '" << xmlFile << "'\n"
              << "Exception message is: \n"
              << StrX(toCatch.getMessage())
              << "\n" << endl;
diff --git a/samples/SAX2Print/SAX2Print.cpp b/samples/SAX2Print/SAX2Print.cpp
index 91700e9f6fbe890ff5a61b88f3c2af0b6bc84fac..873061f287ca20a2daa0753d6137cf66fb9f5d29 100644
--- a/samples/SAX2Print/SAX2Print.cpp
+++ b/samples/SAX2Print/SAX2Print.cpp
@@ -56,6 +56,9 @@
 
 /*
  * $Log$
+ * Revision 1.10  2002/04/17 20:18:08  tng
+ * [Bug 7493] The word "occured" is misspelled and it is a global error.
+ *
  * Revision 1.9  2002/02/13 16:11:06  knoaman
  * Update samples to use SAX2 features/properties constants from XMLUni.
  *
@@ -325,7 +328,7 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& toCatch)
     {
-        cerr << "\nAn error occured\n  Error: "
+        cerr << "\nAn error occurred\n  Error: "
              << StrX(toCatch.getMessage())
              << "\n" << endl;
         XMLPlatformUtils::Terminate();
diff --git a/samples/SAXPrint/SAXPrint.cpp b/samples/SAXPrint/SAXPrint.cpp
index fe92b74c5c34cb154b53c210d0a0d930c7bb03bb..1e00f8cc919daee0e467f5505c9c0467a7a44897 100644
--- a/samples/SAXPrint/SAXPrint.cpp
+++ b/samples/SAXPrint/SAXPrint.cpp
@@ -56,6 +56,9 @@
 
 /*
  * $Log$
+ * Revision 1.20  2002/04/17 20:18:08  tng
+ * [Bug 7493] The word "occured" is misspelled and it is a global error.
+ *
  * Revision 1.19  2002/02/01 22:41:17  peiyongz
  * sane_include
  *
@@ -344,7 +347,7 @@ int main(int argC, char* argV[])
 
     catch (const XMLException& toCatch)
     {
-        cerr << "\nAn error occured\n  Error: "
+        cerr << "\nAn error occurred\n  Error: "
              << StrX(toCatch.getMessage())
              << "\n" << endl;
         XMLPlatformUtils::Terminate();
diff --git a/samples/SEnumVal/SEnumVal.cpp b/samples/SEnumVal/SEnumVal.cpp
index 461d161cff8079eb27a29954231d3a2ca3ac27c3..e10da9acd44fc5becb1215c2a543b029c131ab91 100644
--- a/samples/SEnumVal/SEnumVal.cpp
+++ b/samples/SEnumVal/SEnumVal.cpp
@@ -57,6 +57,9 @@
 /*
  * $Id$
  * $Log$
+ * Revision 1.9  2002/04/17 20:18:08  tng
+ * [Bug 7493] The word "occured" is misspelled and it is a global error.
+ *
  * Revision 1.8  2002/02/20 20:30:11  peiyongz
  * Make the code compilable on Solaris 2.6's CC
  *
@@ -227,7 +230,7 @@ void process(char* const xmlFile)
 
     if (parser.getErrorCount())
 	{
-        cout << "\nErrors occured, no output available\n" << endl;
+        cout << "\nErrors occurred, no output available\n" << endl;
 		return;
 	}
 
diff --git a/tests/EncodingTest/EncodingTest.cpp b/tests/EncodingTest/EncodingTest.cpp
index ff4034392d6cffea1249fab67e223ee5d7f82617..dec4339259421f88a6dbda20fecd42ff77dff737 100644
--- a/tests/EncodingTest/EncodingTest.cpp
+++ b/tests/EncodingTest/EncodingTest.cpp
@@ -147,7 +147,7 @@ static DOM_Document parseFile(char *fileName)
 
     catch (const XMLException& e )
     {
-		fprintf(stderr, "Exception Occured \"%s\".  \n",
+		fprintf(stderr, "Exception Occurred \"%s\".  \n",
 			XMLString::transcode(e.getMessage()));
 		fprintf(stderr, "File being parsed is \"%s\".\n", fileName);
         return DOM_Document();  // A null document.
diff --git a/tests/InitTermTest/InitTermTest.cpp b/tests/InitTermTest/InitTermTest.cpp
index d3316428885a21f303ae0fca19456283f896ce5c..e4b9d10b7b7b017db76a8214d680089d42761f1e 100644
--- a/tests/InitTermTest/InitTermTest.cpp
+++ b/tests/InitTermTest/InitTermTest.cpp
@@ -188,7 +188,7 @@ int TestInit4SAX2(const char* xmlFile, bool gDoNamespaces, bool gDoSchema, bool
                                                                   \
     if (errorHandler.getSawErrors())                              \
     {                                                             \
-        cout << "\nErrors occured, no output available\n" << endl;\
+        cout << "\nErrors occurred, no output available\n" << endl;\
         errorOccurred = true;                                     \
     }                                                             \
                                                                   \
diff --git a/tests/ThreadTest/ThreadTest.cpp b/tests/ThreadTest/ThreadTest.cpp
index 084d1b0b0a933bcdc1fbb60fce239f599621dc23..74138d2921aa352c55d1d9787584e7cc48517726 100644
--- a/tests/ThreadTest/ThreadTest.cpp
+++ b/tests/ThreadTest/ThreadTest.cpp
@@ -302,7 +302,7 @@ public:                               //  This is the API used by the rest of th
     int parse(int fileNum);           // Parse the specified file.  fileNum is an index
                                       //   into the gRunInfo.files array.
                                       //  return the XML checksum, or
                                       //  0 if a parse error occured.
 
     int reCheck();                    // Try to compute the checksum again.
                                       //  for DOM, re-walk the tree.
@@ -1195,7 +1195,7 @@ int main (int argc, char **argv)
 
         if (cksum == 0)
         {
-            fprintf(stderr, "An error occured while initially parsing %s\n",
+            fprintf(stderr, "An error occurred while initially parsing %s\n",
                 fileName);
             errors = true;
         };
@@ -302,7 +302,7 @@ public:                               //  This is the API used by the rest of th
                                       //   into the gRunInfo.files array.
                                       //  return the XML checksum, or
-                                      //  0 if a parse error occured.
+                                      //  0 if a parse error occurred.
 
     int reCheck();                    // Try to compute the checksum again.